.. potoroo

Welcome to potoroo's documentation!
===================================

Python implementations of the Repository and UnitOfWork abstractions.

.. toctree::
   :maxdepth: -1
   :caption: Table of Contents

    API Reference <modules>
    Changelog <changelog>
    Development Guide <contributing>
    README <readme>


Indices and Tables
==================

* :ref:`genindex`
* :ref:`modindex`
